@@ -1,6 +1,6 @@
 
 '''
-BLURB GOES HERE.
+Nuitka BuildTarget
 
 Copyright (c) 2015 - 2022 Rob "N3X15" Nelson <nexisentertainment@gmail.com>
 
@@ -25,7 +25,7 @@ SOFTWARE.
 '''
 import os, sys
 from pathlib import Path
-from typing import List, Optional, Tuple
+from typing import List, Optional, Tuple, Union
 
 from buildtools import os_utils
 from buildtools.maestro.base_target import SingleBuildTarget
@@ -34,7 +34,7 @@ from buildtools.maestro.base_target import SingleBuildTarget
 class NuitkaTarget(SingleBuildTarget):
     BT_LABEL = 'NUITKA'
 
-    def __init__(self, entry_point: str, package_name: str, files: List[str], dependencies: List[str]=[], tmp_dir: Optional[str]=None, single_file: bool=True, nuitka_subdir: str = None) -> None:
+    def __init__(self, entry_point: Union[str, Path], package_name: str, files: List[Union[str, Path]], dependencies: List[Union[str, Path]]=[], tmp_dir: Optional[Union[str, Path]]=None, single_file: bool=True, nuitka_subdir: Optional[Union[str, Path]] = None) -> None:
         if tmp_dir is None:
             tmp_dir = Path('.tmp')
         else:
@@ -57,6 +57,8 @@ class NuitkaTarget(SingleBuildTarget):
         self.windows_file_version: Tuple[int, int, int, int] = (0,0,0,0)
         self.windows_file_description: str = 'FIXME: Review target.windows_product_name, target.windows_company_name, target.windows_file_version, and target.windows_file_description.'
 
+        self.linux_onefile_icon: Optional[Union[str, Path]] = None
+
         super().__init__(target=str(self.executable_mangled), files=files, dependencies=dependencies)
 
         self.included_packages: List[str] = []
@@ -72,16 +74,19 @@ class NuitkaTarget(SingleBuildTarget):
         if os.name != 'nt':
             opts += ['--static-libpython=yes']
         for pkg in self.included_packages:
-            opts += ['--include-package', pkg]
+            opts += [f'--include-package={pkg}']
         for plug in self.enabled_plugins:
-            opts += ['--enable-plugin', plug]
+            opts += [f'--enable-plugin={plug}']
         opts += [
-            '--output-dir', str(self.out_dir),
+            f'--output-dir={self.out_dir}',
             #'--show-progress', # *screaming*
             '--standalone'
         ]
         if self.singlefile:
             opts += ['--onefile']
+            if os_utils.is_linux():
+                if self.linux_onefile_icon is not None:
+                    opts.append(f'--linux-onefile-icon={self.linux_onefile_icon}')
         if os_utils.is_windows():
             opts += [
                 f'--windows-product-name={self.windows_product_name}',
